ambient-toolbox
==============

Welcome to the Ambient Toolbox ``ambient-toolbox``!

Since 2012 we are gathering tools and useful code snippets to share them across projects. The toolbox ``ambient-toolbox``
provides utilities for a wide range of applications. Please have a look at the following chapters to familiarise
yourself with them.

The package is published at pypi under the following link: `https://pypi.org/project/ambient-toolbox/ <https://pypi.org/project/ambient-toolbox/>`_


.. toctree::
   :maxdepth: 1
   :caption: Contents:

   features/setup.md
   features/admin.md
   features/context_manager.md
   features/context_processors.md
   features/database_anonymisation.md
   features/djangorestframework.md
   features/gitlab.md
   features/graphql.md
   features/managers.md
   features/mail.md
   features/models.md
   features/mixins.md
   features/permissions.md
   features/selectors.md
   features/sentry.md
   features/services.md
   features/static_role_permissions.md
   features/tests.md
   features/translations.md
   features/utils.rst
   features/validators.md
   features/view-layer.rst
   features/changelog.md

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
